unit rw_inifiles;

interface

function  INIfile_Create(const FileName: pansichar): pointer; stdcall;
procedure INIfile_Free(p: pointer); stdcall;

procedure INIfile_AutoSaveSet(p: pointer; value: boolean); stdcall;
procedure INIfile_Clear(p: pointer); stdcall;
procedure INIfile_DeleteKey(p: pointer; const Section, Ident: pansichar); stdcall;
procedure INIfile_EraseSection(p: pointer; const Section: pansichar); stdcall;
function  INIfile_ModifiedGet(p: pointer): boolean; stdcall;
function  INIfile_ReadSections(p: pointer): integer; stdcall;
function  INIfile_ReadSectionName(p: pointer; index: integer): pansichar; stdcall;
function  INIfile_SectionExists(p: pointer; const Section: pansichar): Boolean; stdcall;
procedure INIfile_UpdateFile(p: pointer); stdcall;
function  INIfile_ValueExists(p: pointer; const Section, Ident: pansichar): Boolean; stdcall;
function  INIfile_ReadString(p: pointer; const Section, Ident, Default: pansichar): pansichar; stdcall;
function  INIfile_ReadInteger(p: pointer; const Section, Ident: pansichar; Default: Integer): Integer; stdcall;
function  INIfile_ReadFloat(p: pointer; const Section, Ident: pansichar; Default: Double): Double; stdcall;
function  INIfile_ReadBool(p: pointer; const Section, Ident: pansichar; Default: Boolean): Boolean; stdcall;
procedure INIfile_WriteString(p: pointer; const Section, Ident, Value: pansichar); stdcall;
procedure INIfile_WriteInteger(p: pointer; const Section, Ident: pansichar; Value: Integer); stdcall;
procedure INIfile_WriteFloat(p: pointer; const Section, Ident: pansichar; Value: Double); stdcall;
procedure INIfile_WriteBool(p: pointer; const Section, Ident: pansichar; Value: Boolean); stdcall;

exports
  INIfile_AutoSaveSet,
  INIfile_Clear,
  INIfile_Create,
  INIfile_DeleteKey,
  INIfile_EraseSection,
  INIfile_Free,
  INIfile_ModifiedGet,
  INIfile_ReadSections,
  INIfile_ReadSectionName,
  INIfile_SectionExists,
  INIfile_UpdateFile,
  INIfile_ValueExists,
  INIfile_ReadString, INIfile_ReadInteger, INIfile_ReadFloat, INIfile_ReadBool,
  INIfile_WriteString, INIfile_WriteInteger, INIfile_WriteFloat, INIfile_WriteBool;


implementation

uses
  classes,
  inifiles,
  rwnet_functions;

type
  TINIfile2 = class(TMemInifile)
  public
    inifile_sections: TStringList;
  end;

function INIfile_Create(const FileName: pansichar): pointer;
begin
  result:= TINIfile2.Create(filename);
  TINIfile2(result).inifile_sections:= TStringList.Create;
end;

procedure INIfile_Free(p: pointer);
begin
  TINIfile2(p).inifile_sections.Free;
  TINIfile2(p).Free;
end;




procedure INIfile_AutoSaveSet(p: pointer; value: boolean);
begin
  TINIfile2(p).AutoSave:= value;
end;

procedure INIfile_Clear(p: pointer);
begin
  TINIfile2(p).Clear;
end;

procedure INIfile_DeleteKey(p: pointer; const Section, Ident: pansichar);
begin
  TINIfile2(p).DeleteKey(section,ident);
end;

procedure INIfile_EraseSection(p: pointer; const Section: pansichar);
begin
  TINIfile2(p).EraseSection(section);
end;

function INIfile_ModifiedGet(p: pointer): boolean;
begin
  result:= TINIfile2(p).Modified;
end;

function INIfile_ReadSections(p: pointer): integer;
begin
  TINIfile2(p).ReadSections(TINIfile2(p).inifile_sections);
  result:= TINIfile2(p).inifile_sections.Count;
end;

function INIfile_ReadSectionName(p: pointer; index: integer): pansichar;
var
  resultA: ansistring;
begin
  resultA:= TINIfile2(p).inifile_sections[index];
  result:= pansichar(resultA);
end;

function INIfile_SectionExists(p: pointer; const Section: pansichar): Boolean;
begin
  result:= TINIfile2(p).SectionExists(section);
end;

procedure INIfile_UpdateFile(p: pointer);
begin
  TINIfile2(p).UpdateFile;
end;

function INIfile_ValueExists(p: pointer; const Section, Ident: pansichar): Boolean;
begin
  result:= TINIfile2(p).ValueExists(section,ident);
end;

function INIfile_ReadString(p: pointer; const Section, Ident, Default: pansichar): pansichar;
var
  resultA: ansistring;
begin
  resultA:= TINIfile2(p).ReadString(section,ident,default);
  result:= pansichar(resultA);
end;

function INIfile_ReadInteger(p: pointer; const Section, Ident: pansichar; Default: Integer): Integer;
begin
  result:= TINIfile2(p).ReadInteger(section,ident,default);
end;

function INIfile_ReadFloat(p: pointer; const Section, Ident: pansichar; Default: Double): Double;
begin
  result:= strtofloat2(TINIfile2(p).ReadString(section,ident,floattostr2(default)));
end;

function INIfile_ReadBool(p: pointer; const Section, Ident: pansichar; Default: Boolean): Boolean;
begin
  result:= TINIfile2(p).ReadBool(section,ident,default);
end;

procedure INIfile_WriteString(p: pointer; const Section, Ident, Value: pansichar);
begin
  TINIfile2(p).WriteString(section,ident,value);
end;

procedure INIfile_WriteInteger(p: pointer; const Section, Ident: pansichar; Value: Integer);
begin
  TINIfile2(p).WriteInteger(section,ident,value);
end;

procedure INIfile_WriteFloat(p: pointer; const Section, Ident: pansichar; Value: Double);
begin
  TINIfile2(p).WriteString(section,ident,floattostr2(value));
end;

procedure INIfile_WriteBool(p: pointer; const Section, Ident: pansichar; Value: Boolean);
begin
  TINIfile2(p).WriteBool(section,ident,value);
end;

end.
